@@ -7,7 +7,7 @@ from abc import abstractmethod, abstractproperty
 import faust
 import socket
 from dataclasses import dataclass, field
-from typing import Any, Dict, List, Optional, TypeVar, Type
+from typing import Any, Dict, List, Optional, TypeVar, Type, Union
 from delphai_utils.config import get_config
 from faust.types import CodecArg
 from faust.types.models import ModelT
@@ -178,6 +178,7 @@ class FaustApp:
     logging_config: Dict
     faust_config: Dict
     metrics: Service = Service()
+    pipeline_name: str
 
     async def on_startup_finished(self):
         self.logger.info(f"started app {self.app._conf.id}")
@@ -201,7 +202,10 @@ class FaustApp:
         self.worker._disable_spinner_if_level_below_WARN(effective_level)
         self.worker._setup_spinner_handler(logger, effective_level)
 
-    def __init__(self, id: str, broker: str) -> None:
+    def __init__(
+        self, id: str, broker: str, pipeline_name: Union[str, None] = None
+    ) -> None:
+        self.pipeline_name = pipeline_name if pipeline_name is not None else id
         try:
             self.faust_config = get_config("faust")
             if self.faust_config is None:
@@ -264,9 +268,9 @@ class FaustApp:
         step_config = self.get_step_config(step)
         client = AdminClient({"bootstrap.servers": broker.replace("kafka://", "")})
         topics = list(client.list_topics().topics.keys())
-        topic_names = [f"{self.app._conf.id}.{step_config.name}"]
+        topic_names = [f"{self.pipeline_name}.{step_config.name}"]
         for table in step_config.tables:
-            table_topic_name = f"{self.app._conf.id}-{table}-changelog"
+            table_topic_name = f"{self.pipeline_name}-{table}-changelog"
             topic_names.append(table_topic_name)
         for topic_name in topic_names:
             if topic_name not in topics:
